from yacaptcha.fields import YaCaptchaField

from registration.forms import RegistrationForm, RegistrationFormUniqueEmail


# class RegistrationFormCaptcha(RegistrationForm):
#     captcha = ReCaptchaField(attrs={'theme': 'white'})

class RegistrationFormCaptcha(RegistrationFormUniqueEmail):
    captcha = YaCaptchaField()



from django import forms
from django.conf import settings
from django.template.loader import render_to_string
from cleanweb import Cleanweb

DEFAULT_WIDGET_TEMPLATE = 'yacaptcha/widget.html'
WIDGET_TEMPLATE = getattr(settings, "YACAPTCHA_WIDGET_TEMPLATE", DEFAULT_WIDGET_TEMPLATE)


class YaCaptcha(forms.widgets.Widget):
    def __init__(self, key=None, *args, **kwargs):
        self.key = key if key else settings.YACAPTCHA_KEY
        super(YaCaptcha, self).__init__(*args, **kwargs)

    def render(self, name, value, attrs=None):
        client = Cleanweb(key=self.key)
        cap_dict = client.get_captcha()
        return render_to_string(DEFAULT_WIDGET_TEMPLATE,
                                {'yacaptcha_img_url': cap_dict['url'],
                                 'yacaptcha_response_field': cap_dict['captcha']
                                })

    def value_from_datadict(self, data, files, name):
        return [data.get('yacaptcha_challenge_field', None), data.get('yacaptcha_response_field', None)]


from django import forms
from django.core import validators
from cleanweb import Cleanweb
from widgets import YaCaptcha
from django.utils.translation import ugettext_lazy as _


class YaCaptchaField(forms.CharField):
    default_error_messages = {
        'required': _(u'This field is required.'),
        'captcha_invalid': _(u'Incorrect, please try again.')
    }

    def __init__(self, *args, **kwargs):
        self.required = True
        self.widget = YaCaptcha()
        super(YaCaptchaField, self).__init__(*args, **kwargs)

    def to_python(self, value):
        if value in validators.EMPTY_VALUES:
            return None
        return value

    def validate(self, values):
        super(YaCaptchaField, self).validate(values[0])
        recaptcha_challenge_value = values[0]
        recaptcha_response_value = values[1]

        client = Cleanweb(key=self.widget.key)

        check = client.check_captcha(captcha=recaptcha_response_value, value=recaptcha_challenge_value)
        if not check:
            raise forms.ValidationError(self.error_messages['captcha_invalid'])


from setuptools import setup, find_packages
import os

try:
    from setuptest import test
except ImportError:
    from setuptools.command.test import test

version = '0.0.1'

def read(fname):
    # read the contents of a text file
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "django-yacaptcha",
    version = version,
    url = 'https://github.com/Atomic-Creative/django-yacaptcha',
    license = 'BSD',
    platforms=['OS Independent'],
    description = "Simple captcha with Yandex API.",
    long_description = read('README.md'),
    author = 'avigmati',
    author_email = 'avigmati@gmail.com',
    packages=find_packages(),
    install_requires = (
        'Django>=1.3',
	'cleanweb',
    ),
    include_package_data=True,
    zip_safe=False,
    classifiers = [
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ],
)
